@@ -35,6 +35,8 @@ from .tools import (
     tsvd,
     tsvd_transform,
     regress_out,
+    nmf,
+    integrative_nmf,
     highly_variable_features,
     set_group_attribute,
     correct_batch,
@@ -48,6 +50,7 @@ from .tools import (
     calc_pseudotime,
     jump_method,
     cluster,
+    split_one_cluster,
     louvain,
     leiden,
     spectral_louvain,
@@ -67,7 +70,7 @@ from .tools import (
     mark_doublets,
 )
 from .annotate_cluster import infer_cell_types, annotate, infer_cluster_names
-from .misc import search_genes, search_de_genes
+from .misc import search_genes, search_de_genes, find_outlier_clusters
 from .plotting import (
     scatter,
     compo_plot,
@@ -81,6 +84,7 @@ from .plotting import (
     volcano,
     rank_plot,
     ridgeplot,
+    wordcloud,
 )
 
 try:
