@@ -1,4 +1,3 @@
-import time
 import numpy as np
 import pandas as pd
 
@@ -22,12 +21,12 @@ def qc_metrics(
     select_singlets: bool = False,
     remap_string: str = None,
     subset_string: str = None,
-    min_genes: int = 500,
-    max_genes: int = 6000,
+    min_genes: int = None,
+    max_genes: int = None,
     min_umis: int = None,
     max_umis: int = None,
-    mito_prefix: str = "MT-",
-    percent_mito: float = 20.0,
+    mito_prefix: str = None,
+    percent_mito: float = None,
 ) -> None:
     """Generate Quality Control (QC) metrics regarding cell barcodes on the dataset.
 
@@ -41,17 +40,17 @@ def qc_metrics(
         Remap singlet names using <remap_string>, where <remap_string> takes the format "new_name_i:old_name_1,old_name_2;new_name_ii:old_name_3;...". For example, if we hashed 5 libraries from 3 samples sample1_lib1, sample1_lib2, sample2_lib1, sample2_lib2 and sample3, we can remap them to 3 samples using this string: "sample1:sample1_lib1,sample1_lib2;sample2:sample2_lib1,sample2_lib2". In this way, the new singlet names will be in metadata field with key 'assignment', while the old names will be kept in metadata field with key 'assignment.orig'.
     subset_string: ``str``, optional, default ``None``
         If select singlets, only select singlets in the <subset_string>, which takes the format "name1,name2,...". Note that if --remap-singlets is specified, subsetting happens after remapping. For example, we can only select singlets from sampe 1 and 3 using "sample1,sample3".
-    min_genes: ``int``, optional, default: ``500``
+    min_genes: ``int``, optional, default: ``None``
        Only keep cells with at least ``min_genes`` genes.
-    max_genes: ``int``, optional, default: ``6000``
+    max_genes: ``int``, optional, default: ``None``
        Only keep cells with less than ``max_genes`` genes.
     min_umis: ``int``, optional, default: ``None``
        Only keep cells with at least ``min_umis`` UMIs.
     max_umis: ``int``, optional, default: ``None``
        Only keep cells with less than ``max_umis`` UMIs.
-    mito_prefix: ``str``, optional, default: ``MT-``
+    mito_prefix: ``str``, optional, default: ``None``
        Prefix for mitochondrial genes.
-    percent_mito: ``float``, optional, default: ``20.0``
+    percent_mito: ``float``, optional, default: ``None``
        Only keep cells with percent mitochondrial genes less than ``percent_mito`` % of total counts.
 
     Returns
@@ -68,17 +67,10 @@ def qc_metrics(
 
     Examples
     --------
-    >>> pg.qc_metrics(data)
+    >>> pg.qc_metrics(data, min_genes=500, max_genes=6000, mito_prefix="MT-", percent_mito=10)
     """
     if isinstance(data, MultimodalData):
         data = data.current_data()
-
-    # Make sure that n_genes and n_counts statistics are calculated by setting min_genes = 1 and min_umis = 1
-    if min_genes is None:
-        min_genes = 1
-    if min_umis is None:
-        min_umis = 1
-
     calc_qc_filters(data, select_singlets = select_singlets, remap_string = remap_string, subset_string = subset_string, min_genes = min_genes, max_genes = max_genes, min_umis = min_umis, max_umis = max_umis, mito_prefix = mito_prefix, percent_mito = percent_mito)
 
 
@@ -168,7 +160,7 @@ def filter_data(data: MultimodalData, focus_list: List[str] = None) -> None:
     --------
     >>> pg.filter_data(data)
     """
-    data.filter_data(focus_list = focus_list, cache_passqc = True)
+    data.filter_data(focus_list = focus_list, cache_passqc = True, uns_white_list="norm_count,df_qcplot")
 
 
 @timer(logger=logger)
@@ -302,7 +294,7 @@ def _run_filter_data(
 
 @timer(logger=logger)
 def log_norm(
-    data: MultimodalData, 
+    data: Union[MultimodalData, UnimodalData],
     norm_count: float = 1e5, 
     backup_matrix: str = "raw.X",
 ) -> None:
@@ -350,36 +342,28 @@ def log_norm(
 
 @run_gc
 def select_features(
-    data: MultimodalData,
+    data: Union[MultimodalData, UnimodalData],
     features: str = "highly_variable_features",
     standardize: bool = True,
     max_value: float = 10.0,
 ) -> str:
     """ Subset the features and store the resulting matrix in dense format in data.uns with `'_tmp_fmat_'` prefix, with the option of standardization and truncating based on max_value. `'_tmp_fmat_*'` will be removed before writing out the disk.
-
     Parameters
     ----------
     data: ``pegasusio.MultimodalData``
         Annotated data matrix with rows for cells and columns for genes.
-
-    features: ``str``, optional, default: ``None``.
+    features: ``str``, optional, default: ``highly_variable_features``.
         a keyword in ``data.var``, which refers to a boolean array. If ``None``, all features will be selected.
-
     standardize: ``bool``, optional, default: ``True``.
         Whether to scale the data to unit variance and zero mean.
-
     max_value: ``float``, optional, default: ``10``.
         The threshold to truncate data after scaling. If ``None``, do not truncate.
-
     Returns
     -------
     keyword: ``str``
         The keyword in ``data.uns`` referring to the features selected.
-
     Update ``data.uns`` if needed:
-
         * ``data.uns[keyword]``: A submatrix of the data containing features selected.
-
     Examples
     --------
     >>> pg.select_features(data)
@@ -423,7 +407,7 @@ def select_features(
 
 @timer(logger=logger)
 def pca(
-    data: MultimodalData,
+    data: Union[MultimodalData, UnimodalData],
     n_components: int = 50,
     features: str = "highly_variable_features",
     standardize: bool = True,
@@ -474,6 +458,8 @@ def pca(
 
         * ``data.uns["pca_variance_ratio"]``: Ratio of explained variance.
 
+        * ``data.uns["pca_features"]``: Record the features used to generate PCA components.
+
     Examples
     --------
     >>> pg.pca(data)
@@ -496,7 +482,7 @@ def pca(
 
 @timer(logger=logger)
 def pc_transform(
-    data: MultimodalData,
+    data: Union[MultimodalData, UnimodalData],
     X: Union[csr_matrix, np.ndarray]
 ) -> np.ndarray:
     """Transform a new count matrix X using existing PCs contained in data.
